/*
 * Copyright 2013 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.gradle.api.plugins.cloudbees.tasks.app

import com.cloudbees.api.ApplicationInfo
import org.gradle.api.plugins.cloudbees.client.CloudBeesClient
import org.gradle.api.plugins.cloudbees.tasks.CloudBeesTask
import org.gradle.api.tasks.Input

/**
 * Returns the basic information about an application.
 *
 * @author Benjamin Muschko
 */
class CloudBeesAppInfo extends CloudBeesTask {
    /**
     * Application identifier.
     */
    @Input
    String appId

    CloudBeesAppInfo() {
        super('Returns the basic information about an application.')
    }

    @Override
    void executeAction(CloudBeesClient client) {
        ApplicationInfo info = client.applicationInfo(getAppId())
        logger.quiet "Application title : $info.title"
        logger.quiet "          created : $info.created"
        logger.quiet "             urls : $info.urls"
        logger.quiet "           status : $info.status"
    }
}